@@ -3,7 +3,8 @@
 #' Format for creating submissions to Copernicus journals.
 #'
 #' @inheritParams rmarkdown::pdf_document
-#' @param ... Additional arguments to \code{rmarkdown::pdf_document()}.
+#' @param ... Additional arguments to \code{rmarkdown::pdf_document()}. \bold{Note}: \code{extra_dependencies} are not
+#' allowed as Copernicus does not support additional packages included via \code{\\usepackage{}}.
 #' @param journal_name A regular expression to filter the by the journal name, see \code{pattern} in \code{\link[base]{grep}}; defaults to \code{*}.
 #'
 #' @return An R Markdown output format.
@@ -12,13 +13,13 @@
 #'
 #' An number of required and optional manuscript sections, e.g. \code{acknowledgements}, \code{competinginterests}, or \code{authorcontribution}, must be declared using the respective properties of the R Markdown header - see skeleton file.
 #'
-#' \strong{Version:} Based on copernicus_package.zip in the version 5.3, 18 February 2019, using \code{copernicus.cls} in version 8.82.
+#' \strong{Version:} Based on \code{copernicus_package.zip} in the version 6.2, 15 January 2021, using \code{copernicus.cls} in version 9.25.
 #'
-#' \strong{Copernicus journal abbreviations:} You can use the function \code{copernicus_journal_abbreviations()} to get the journal abbreviation for all journals supported by the copernicus article template.
+#' \strong{Copernicus journal abbreviations:} You can use the function \code{copernicus_journal_abbreviations()} to get the journal abbreviation for all journals supported by the Copernicus article template.
 #'
 #' \strong{Important note:} The online guidelines by Copernicus are the official resource.
 #' Copernicus is not responsible for the community contributions made to support the template in this package.
-#' Copenicus converts all typeset TeX files into XML, the expressions and markups have to be highly standardized.
+#' Copernicus converts all typeset TeX files into XML, the expressions and markups have to be highly standardized.
 #' Therefore, please keep the following in mind:
 #'
 #' \itemize{
@@ -26,7 +27,9 @@
 #'   \item Please use only commands in which words, numbers, etc. are within braces (e.g. \code{\\textrm{TEXT}} instead of \code{{\\rm TEXT}}).
 #'   \item For algorithms, please use the syntax given in template.tex or provide your algorithm as a figure.
 #'   \item Please do not define new commands.
-#'   \item The most commonly used packages (\code{\\usepackage{}}) are integrated in the copernicus.cls. Some other packages often used by the community are defined in template.tex. Please do not insert additional ones in your *.tex file.
+#'   \item Supported packages (\code{\\usepackage{}}) are already integrated in the \code{copernicus.cls}.  Please do not insert additional ones in your \code{*.tex} file.
+#'   \item If you opt for syntax highlighting for your preprint or other reasons, please do not forget to use
+#'    \code{highlight = NULL} for your final file upload once your manuscript was accepted for publication.
 #'   \item Spaces in labels (\code{\\label{}}) are not allowed; please make sure that no label name is assigned more than once.
 #'   \item Please do not use \code{\\paragraph{}}; only \code{\\subsubsection{}} is allowed.
 #'   \item It is not possible to add tables in colour.
@@ -48,14 +51,21 @@
 #' }
 #' @export
 copernicus_article <- function(
-  ..., keep_tex = TRUE, citation_package = "natbib", md_extensions = c(
+  ..., keep_tex = TRUE, highlight = NULL, citation_package = "natbib", md_extensions = c(
     "-autolink_bare_uris", # disables automatic links, needed for plain email in \correspondence
     "-auto_identifiers"    # disables \hypertarget commands
   )
 ) {
+  if ("extra_dependencies" %in% names(list(...)))
+    warning(
+      "Copernicus does not support additional LaTeX packages and options!
+          >> Please remove 'extra_dependencies' from your YAML header!",
+      call. = FALSE
+    )
+
   pdf_document_format(
     "copernicus", citation_package = citation_package,
-    keep_tex = keep_tex, md_extensions = md_extensions, ...
+    keep_tex = keep_tex, highlight = highlight, md_extensions = md_extensions, ...
   )
 }
 
